@@ -4,7 +4,7 @@ use warnings;
 
 {
     no strict "vars";
-    $VERSION = "1.08";
+    $VERSION = "1.09";
 }
 
 use Acme::CPANAuthors::Register (
@@ -25,11 +25,12 @@ use Acme::CPANAuthors::Register (
     'GETTY'         => 'Torsten Raudssus',
     'GUGOD'         => 'Liu Kang Min',
     'INGY'          => 'Ingy dot Net',
+    'JGNI'          => 'John Imrie',
     'KENTNL'        => 'Kent Fredric',
     'LBROCARD'      => 'Leon Brocard',
     'LEOCHARRE'     => 'Leo Charre',
     'MANWAR'        => 'Mohammad S Anwar',
-    'MARCEL'        => 'Marcel Gruenauer',
+    'MARCEL'        => '???',
     'MIYAGAWA'      => 'Tatsuhiko Miyagawa',
     'MLEHMANN'      => '???',
     'MRAMBERG'      => 'Marcus Ramberg',
@@ -38,6 +39,7 @@ use Acme::CPANAuthors::Register (
     'PERLANCAR'     => 'perlancar',
     'PEVANS'        => 'Paul Evans',
     'PLICEASE'      => 'Graham Ollis',
+    'PSIXDISTS'     => 'Perl 6 Modules',
     'RJBS'          => 'Ricardo SIGNES',
     'RSAVAGE'       => 'Ron Savage',
     'SALVA'         => 'Salvador Fandino Garcia',
@@ -90,49 +92,51 @@ See L<http://backpan.cpantesters.org>.
 
 =head1 THE AUTHORS
 
-   1.  507  SHARYANTO     Steven Haryanto
-   2.  497  PERLANCAR     perlancar
-   3.  313  TOBYINK       Toby Inkster
-   4.  302  RJBS          Ricardo SIGNES
-   5.  287  ADAMK         Adam Kennedy
-   6.  279  ZOFFIX        Zoffix Znet
-   7.  251  TOKUHIROM     ???
-   8.  239  MIYAGAWA      Tatsuhiko Miyagawa
-   9.  218  INGY          Ingy dot Net
-  10.  215  BINGOS        Chris Williams
-  11.  210  FLORA         Florian Ragwitz
-  12.  205  ETHER         Karen Etheridge
-  13.  194  DAGOLDEN      David Golden
-  14.  192  SMUELLER      Steffen Mueller
-  15.  182  MARCEL        Marcel Gruenauer
-  16.  172  BOBTFISH      Tomas Doran
-  17.  167  KENTNL        Kent Fredric
-  18.  161  NUFFIN        Yuval Kogman
-  19.  152  DROLSKY       Dave Rolsky
-  20.  138  GUGOD         Liu Kang Min
-  21.  137  DMAKI         Daisuke Maki
-  22.  136  PEVANS        Paul Evans
-  23.  134  BARBIE        Barbie
-  24.  134  RSAVAGE       Ron Savage
-  25.  131  BDFOY         brian d foy
-  26.  125  AUTRIJUS      Audrey Tang
-  27.  124  NEILB         Neil Bowers
-  28.  121  FAYLAND       Fayland Lin
-  29.  121  SIMON         Simon Cozens
-  30.  121  SKIM          Michal Spacek
-  31.  120  SZABGAB       Gabor Szabo
-  32.  117  SHLOMIF       Shlomi Fish
-  33.  113  PLICEASE      Graham Ollis
-  34.  111  LBROCARD      Leon Brocard
-  35.  110  MLEHMANN      ???
-  36.  110  MRAMBERG      Marcus Ramberg
-  37.  109  DMUEY         Daniel Muey
-  38.  108  SALVA         Salvador Fandino Garcia
-  39.  104  GETTY         Torsten Raudssus
-  40.  101  LEOCHARRE     Leo Charre
-  41.  100  MANWAR        Mohammad S Anwar
+   1.  888  PERLANCAR     perlancar
+   2.  510  SHARYANTO     Steven Haryanto
+   3.  479  PSIXDISTS     Perl 6 Modules
+   4.  313  TOBYINK       Toby Inkster
+   5.  309  RJBS          Ricardo SIGNES
+   6.  293  ZOFFIX        Zoffix Znet
+   7.  287  ADAMK         Adam Kennedy
+   8.  251  TOKUHIROM     ???
+   9.  240  MIYAGAWA      Tatsuhiko Miyagawa
+  10.  222  ETHER         Karen Etheridge
+  11.  218  INGY          Ingy dot Net
+  12.  217  BINGOS        Chris Williams
+  13.  210  FLORA         Florian Ragwitz
+  14.  202  JGNI          John Imrie
+  15.  195  DAGOLDEN      David Golden
+  16.  192  SMUELLER      Steffen Mueller
+  17.  182  MARCEL        ???
+  18.  174  KENTNL        Kent Fredric
+  19.  172  BOBTFISH      Tomas Doran
+  20.  161  NUFFIN        Yuval Kogman
+  21.  156  DROLSKY       Dave Rolsky
+  22.  149  PEVANS        Paul Evans
+  23.  138  GUGOD         Liu Kang Min
+  24.  138  RSAVAGE       Ron Savage
+  25.  137  DMAKI         Daisuke Maki
+  26.  137  NEILB         Neil Bowers
+  27.  137  SKIM          Michal Spacek
+  28.  134  BARBIE        Barbie
+  29.  133  BDFOY         brian d foy
+  30.  126  PLICEASE      Graham Ollis
+  31.  125  AUTRIJUS      Audrey Tang
+  32.  125  SHLOMIF       Shlomi Fish
+  33.  122  FAYLAND       Fayland Lin
+  34.  122  SZABGAB       Gabor Szabo
+  35.  121  SIMON         Simon Cozens
+  36.  120  MANWAR        Mohammad S Anwar
+  37.  111  LBROCARD      Leon Brocard
+  38.  111  MLEHMANN      ???
+  39.  111  MRAMBERG      Marcus Ramberg
+  40.  111  SALVA         Salvador Fandino Garcia
+  41.  109  DMUEY         Daniel Muey
+  42.  105  GETTY         Torsten Raudssus
+  43.  101  LEOCHARRE     Leo Charre
 
-List last updated: 2015-08-16T14:12:00
+List last updated: 2016-04-22T05:57:08
 
 =head1 MAINTENANCE
 
@@ -183,7 +187,7 @@ Thanks to Kenichi Ishigaki for writing C<Acme::CPANAuthors>.
 
 =head1 COPYRIGHT & LICENSE
 
-  Copyright 2014-2015 Barbie for Miss Barbell Productions.
+  Copyright 2014-2016 Barbie for Miss Barbell Productions.
 
   This distribution is free software; you can redistribute it and/or
   modify it under the Artistic License 2.0.
